@@ -32,7 +32,7 @@ after {
 sub pass_permission {
     my( $obj, $acct, $cmd, $data, $msg ) = @_;
     eval {
-	$obj->$cmd( $data, $acct );
+        $obj->$cmd( $data, $acct );
     };
     my $err = $@;
     $err =~ s/at \/\S+\.pm.*//s;
@@ -42,7 +42,7 @@ sub pass_permission {
 sub fail_permission {
     my( $obj, $acct, $cmd, $data, $msg ) = @_;
     eval {
-	$obj->$cmd( $data, $acct );
+        $obj->$cmd( $data, $acct );
     };
     my $err = $@;
     $err =~ s/ at \/\S+\.pm.*//s;
@@ -251,8 +251,8 @@ sub io_independent_tests {
     is_deeply( $root_3, $root, "recursive data structure" );
 
     is_deeply( $root_3->get_obj(), $new_obj, "setting object" );
-
     is( $root_3->count( { name => 'array' } ), 6, 'Array has 6 with count' );
+
     is_deeply( $root_3->_paginate( { name => 'array', limit => 3 } ), [ 'THIS IS AN ARRAY', 'With more than one thing', 'MORE STUFF' ], 'paginate limit 3' );
     is_deeply( $root_3->_paginate( { name => 'array', limit => 3, reverse => 1 } ), [ 'MORE STUFF', 'MORE STUFF', 'MORE STUFF' ], 'paginate reverse limit 3' );
     is_deeply( $root_3->_paginate( { name => 'array', limit => 1, skip => 2 } ), [ 'MORE STUFF' ], 'paginate limit three from 2' );
@@ -335,6 +335,7 @@ sub io_independent_tests {
 #
 #                                          #
     $root = Yote::ObjProvider::fetch( Yote::ObjProvider::first_id() );
+
     Yote::ObjProvider::stow_all();
     eval {
         $root->create_login();
@@ -352,12 +353,12 @@ sub io_independent_tests {
     Yote::ObjProvider::stow_all();
     my $root_login = $root->_hash_fetch( "_handles", "root");
     my $root_acct = new Yote::Account( { login => $root_login } );
-    
 
     unless( $root_login ) {
         fail( "Root not loaded" );
         BAIL_OUT("cannot continue" );
     }
+
     is( $root->_count({ name => "_handles" }), 1, "1 handle stored");
     is( $root_login->get_handle(), 'root', 'handle set' );
     is( $root_login->get_email(), 'foo@bar.com', 'email set' );
@@ -387,7 +388,7 @@ sub io_independent_tests {
     $res = $root->_update_master_root( 'realroot', $rpass );
     my $master_account = new Yote::Account( { login => $res } );
     eval {
-	my $rrl = $root->login( { h => 'realroot', p => 'wrongpass' } );
+        my $rrl = $root->login( { h => 'realroot', p => 'wrongpass' } );
     };
     like( $@, qr/incorrect login/i, "Wrong log in" );
     my $rrl = $root->login( { h => 'realroot', p => 'realpass' } );
@@ -433,6 +434,7 @@ sub io_independent_tests {
     is( $root->_hash_fetch( "hashfoo", "zort"), "zot", "hash_fetch with hash" );
 
     Yote::ObjProvider::stow_all();
+
     my $app = $root->_hash_fetch( '_apps', 'Yote::Test::TestAppNeedsLogin' );
     $app->add_to_azzy( "A","B","C","D");
     Yote::ObjProvider::stow_all();
@@ -497,9 +499,9 @@ sub io_independent_tests {
     is_deeply( $res, { 'Bingo' => "BARFO" }, ' paginate for hash using hashkey_search with nonhit search term' );
 
     $res = $app->_paginate( { name => 'hsh', return_hash => 1, search_terms => [ "R" ] } );
-    is_deeply( $res, { 'Bingo' => "BARFO" }, ' search_terms for hash using hashkey_search with nonhit search term' );
+    is_deeply( $res, { 'Bingo' => "BARFO" }, ' search_terms for hash using return_hash with nonhit search term' );
 
-    $res = $app->_paginate( { name => 'hsh', return_hash => 1, search_terms => [ "g" ], hashkey_search => [ "Z" ] } );
+    $res = $app->_paginate( { name => 'hsh', return_hash => 1, search_terms => [ "O" ], hashkey_search => [ "Z" ] } );
     is_deeply( $res, { 'baz/bof' => "FOOME" }, ' search_terms for hash using search terma and hashkey_search with nonhit search term' );
     my $count = $app->_count( { name => 'hsh', return_hash => 1, search_terms => [ "g" ], hashkey_search => [ "Z" ] } );
     is( $count, 1, "one results for count using hash and hashkey and search terms" );
@@ -544,16 +546,16 @@ sub io_independent_tests {
 
     # test search_list
     $o->add_to_searchlist( new Yote::Obj( { n => "one", a => "foobie", b => "oobie", c => "goobol" } ),
-			   new Yote::Obj( { n => "two", a => "bar", b => "car", c => "war" } ),
-			   new Yote::Obj( { n => "three", c => "foobie", b => "xxx" } ),
-			   new Yote::Obj( { n => "four", 'q' => "foobie", b => "xxx" } ),
-			   new Yote::Obj( { n => "five", a => "foobie", b => "car", c => "war" } ),
-	);
+                           new Yote::Obj( { n => "two", a => "bar", b => "car", c => "war" } ),
+                           new Yote::Obj( { n => "three", c => "foobie", b => "xxx" } ),
+                           new Yote::Obj( { n => "four", 'q' => "foobie", b => "xxx" } ),
+                           new Yote::Obj( { n => "five", a => "foobie", b => "car", c => "war" } ),
+        );
     Yote::ObjProvider::stow_all();
 
     $res = $o->_count( { name => 'searchlist', search_fields => [ 'a' ], search_terms => [ 'foobie' ] } );
     is( $res, 2, "Two search resultscount" );
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a' ], search_terms => [ 'foobie' ] } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a' ], search_terms => [ 'foobie'] } );
     is( @$res, 2, "Two search results" );
     my $searchlist = $o->get_searchlist();
     my %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 0, 4 );
@@ -567,22 +569,22 @@ sub io_independent_tests {
     $searchlist = $o->get_searchlist();
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 4, 0 );
     %resids = map { $_->{ID} => 1 } @$res;
-    is_deeply( \%ids, \%resids, "Got correct search matches" );
+    is_deeply( \%resids, \%ids, "Got correct search matches" );
 
 
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ] } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ] } );
     is( @$res, 3, "Three search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 0, 2, 4 );
     %resids = map { $_->{ID} => 1 } @$res;
     is_deeply( \%ids, \%resids, "Got correct search matches" );
 
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ], limit => 2 } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ], limit => 2 } );
     is( @$res, 2, "Two paginated search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 0, 2 );
     %resids = map { $_->{ID} => 1 } @$res;
     is_deeply( \%ids, \%resids, "Got correct search matches. limited" );
 
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ], limit => 2, skip => 1 } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ], limit => 2, skip => 1 } );
     is( @$res, 2, "Two paginated search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 2, 4 );
     %resids = map { $_->{ID} => 1 } @$res;
@@ -596,23 +598,23 @@ sub io_independent_tests {
     %resids = map { $_->{ID} => 1 } @$res;
     is_deeply( \%ids, \%resids, "Got correct search matches" );
     is( $o->count( { name => 'searchlist', search_fields => [ 'a' ], search_terms => [ 'foobie' ] } ), 2, "2 returned from count search" );
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ] } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ] } );
     is( @$res, 3, "Three search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 0, 2, 4 );
     %resids = map { $_->{ID} => 1 } @$res;
     is_deeply( \%ids, \%resids, "Got correct search matches" );
 
-    is( $o->count( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ] } ), 3, "3 returned from count search" );
+    is( $o->count( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ] } ), 3, "3 returned from count search" );
 
 
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ], limit => 2 } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ], limit => 2 } );
     is( @$res, 2, "Two paginated search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 0, 2 );
     %resids = map { $_->{ID} => 1 } @$res;
     is_deeply( \%ids, \%resids, "Got correct search matches. limited" );
-    is( $o->count( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ] } ), 3, "3 returned from count search" );
+    is( $o->count( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ] } ), 3, "3 returned from count search" );
 
-    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie' ], limit => 2, skip => 1 } );
+    $res = $o->paginate( { name => 'searchlist', search_fields => [ 'a', 'c' ], search_terms => [ 'foobie', 'foobie' ], limit => 2, skip => 1 } );
     is( @$res, 2, "Two paginated search results" );
     %ids = map { $searchlist->[ $_ ]->{ID} => 1 } ( 2, 4 );
     %resids = map { $_->{ID} => 1 } @$res;
@@ -622,57 +624,57 @@ sub io_independent_tests {
     $o->add_to_searchlist( new Yote::Obj( { n => "one", a => "aoobie", b => "oobie" } ) );
     Yote::ObjProvider::stow_all();
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ] } );
     my @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 5, 0, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], reversed_orders => [ 1, 1 ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], reversed_orders => [ 1, 1 ] } );
     @ids = map { $searchlist->[ $_ ]->{ID} } reverse( 4, 3, 5, 0, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct reversed sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], reversed_orders => [ 0, 1 ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], reversed_orders => [ 1, 0 ] } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 0, 5, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct mixed sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 3} );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 3} );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 5 );
 
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct limited sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 4, skip => 2} );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 4, skip => 2} );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 5, 0, 2, 1 );
     is( 4, @$res, "lim sort 4 results" );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct sort order pag" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 8, skip => 3 } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 8, skip => 3 } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 2, 1 );
     is( 3, @$res, "pag sort 3 results" );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct pag sort order" );
 
 
     # paginate for sort
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ] } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 5, 0, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], reversed_orders => [ 1, 1 ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], reversed_orders => [ 1, 1 ] } );
     @ids = map { $searchlist->[ $_ ]->{ID} } reverse( 4, 3, 5, 0, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct reversed sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], reversed_orders => [ 0, 1 ] } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], reversed_orders => [ 1, 0 ] } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 0, 5, 2, 1 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct mixed sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 3 } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 3 } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 4, 3, 5 );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct limited sort order" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 4, skip => 2 } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 4, skip => 2 } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 5, 0, 2, 1 );
     is( 4, @$res, "lim sort 4 results" );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct sort order pag" );
 
-    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'n', 'a' ], limit => 8, skip => 3 } );
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [ 'a', 'n' ], limit => 8, skip => 3 } );
     @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 2, 1 );
     is( 3, @$res, "pag sort 3 results" );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct pag sort order" );
@@ -711,14 +713,14 @@ sub io_independent_tests {
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty  search terms and sort_fields no problemo" );
 
     my $num_objs = [
-	new Yote::Obj( { n => 1, l => "C", l2 => "D"    } ), #0
-	new Yote::Obj( { n => 2, l => "D", l2 => "D"   } ),  #1
-	new Yote::Obj( { n => 5, l => "E", l2 => "A"      } ), # 2
-	new Yote::Obj( { n => 20, l => "G", l2=>"D"         } ), #3
-	new Yote::Obj( { n => 22, l => "B", l2 => "B"          } ), #4
-	new Yote::Obj( { n => 100, l => "A" , l2 => "Q"       } ),  #5
-	new Yote::Obj( { n => 1000, l => "F", l2=> "A"        } ), #6
-	];
+        new Yote::Obj( { n => 1, l => "C", l2 => "D"    } ), #0
+        new Yote::Obj( { n => 2, l => "D", l2 => "D"   } ),  #1
+        new Yote::Obj( { n => 5, l => "E", l2 => "A"      } ), # 2
+        new Yote::Obj( { n => 20, l => "G", l2=>"D"         } ), #3
+        new Yote::Obj( { n => 22, l => "B", l2 => "B"          } ), #4
+        new Yote::Obj( { n => 100, l => "A" , l2 => "Q"       } ),  #5
+        new Yote::Obj( { n => 1000, l => "F", l2=> "A"        } ), #6
+        ];
     $new_obj->set_llama( $num_objs );
     Yote::ObjProvider::stow_all();
     $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'n' ], numeric_fields => [ 1 ] } );
@@ -730,10 +732,10 @@ sub io_independent_tests {
     $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'n' ], numeric_fields => [ 0 ] } );
     is_deeply( $res, [ map { $num_objs->[ $_ ] } ( 0, 5, 6, 1, 3, 4, 2 ) ], "Non Numeric sort" );
 
-    $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'l2', 'n' ], numeric_fields => [ 0, 1 ] } );
+    $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'n', 'l2' ], numeric_fields => [ 1, 0 ] } );
     is_deeply( $res, [ map { $num_objs->[ $_ ] } ( 2, 6, 4, 0, 1, 3, 5  ) ], "Mixed" );
 
-    $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'l2', 'n' ], numeric_fields => [ 0, 0 ] } );
+    $res = $new_obj->paginate( { name => 'llama', sort_fields => [ 'n', 'l2' ], numeric_fields => [ 0, 0 ] } );
     is_deeply( $res, [ map { $num_objs->[ $_ ] } ( 6, 2, 4, 0, 1, 3, 5  ) ], "Mixed nonnum" );
 
     my $nums = [ qw/1 5 10 100 2 22/ ];
@@ -755,19 +757,19 @@ sub io_independent_tests {
     #
     # Make sure named list operations properly integrate with recycling/garbage collection.
     #
-    Yote::ObjProvider::recycle_objects();
+    my $rc = Yote::ObjProvider::recycle_objects();
     {
-	my $o2a = new Yote::Obj( { name => "Test for list add to w/ recycling" } );
-	my $o2b = new Yote::Obj( { name => "An other Test for list add to w/ recycling" } );
-	$root->_add_to( 'o_list', $o2a );
-	$root->_add_to( 'o_list', $o2b );
-	Yote::ObjProvider::stow_all();
-	is( $root->_container_type( 'o_list' ), 'ARRAY', 'container type detect list' );
-	my $objs = Yote::ObjProvider::recycle_objects();
-	is( $objs, 0, 'add_to(  not recycled' );
-	$root->_remove_from( 'o_list', $o2a );
-	$root->_remove_from( 'o_list', $o2b );
-	Yote::ObjProvider::stow_all();
+        my $o2a = new Yote::Obj( { name => "Test for list add to w/ recycling" } );
+        my $o2b = new Yote::Obj( { name => "An other Test for list add to w/ recycling" } );
+        $root->_add_to( 'o_list', $o2a );
+        $root->_add_to( 'o_list', $o2b );
+        Yote::ObjProvider::stow_all();
+        is( $root->_container_type( 'o_list' ), 'ARRAY', 'container type detect list' );
+        my $objs = Yote::ObjProvider::recycle_objects();
+        ok( !$objs, 'add_to(  not recycled )' );
+        $root->_remove_from( 'o_list', $o2a );
+        $root->_remove_from( 'o_list', $o2b );
+        Yote::ObjProvider::stow_all();
     }
     my $objs = Yote::ObjProvider::recycle_objects();
     is( $objs, 2, 'remove_from(  is recycled' );
@@ -778,37 +780,41 @@ sub io_independent_tests {
     is( $root->_container_type( 'o_list' ), '', 'container type detect no class once list removed' );
 
     {
-	my $o2a = new Yote::Obj( { name => "yet Test for list add to w/ recycling" } );
-	my $o2b = new Yote::Obj( { name => "yet An other Test for list add to w/ recycling" } );
-	$root->_hash_insert( 'o_hash', "KEYA", $o2a );
-	$root->_hash_insert( 'o_hash', "KEYB", $o2b );
-	Yote::ObjProvider::stow_all();
-	is( $root->_container_type( 'o_hash' ), 'HASH', 'container type detect hash' );
-	my $objs = Yote::ObjProvider::recycle_objects();
-	is( $objs, 0, 'hash(  not recycled' );
-	$root->_hash_delete( 'o_hash', "KEYA" );
-	$root->_hash_delete( 'o_hash', "KEYB" );
-	Yote::ObjProvider::stow_all();	
+        my $o2a = new Yote::Obj( { name => "yet Test for list add to w/ recycling" } );
+        my $o2b = new Yote::Obj( { name => "yet An other Test for list add to w/ recycling" } );
+        $root->_hash_insert( 'o_hash', "KEYA", $o2a );
+        $root->_hash_insert( 'o_hash', "KEYB", $o2b );
+        Yote::ObjProvider::stow_all();
+        is( $root->_container_type( 'o_hash' ), 'HASH', 'container type detect hash' );
+        my $objs = Yote::ObjProvider::recycle_objects();
+        is( $objs, 0, 'hash(  not recycled' );
+        $root->_hash_delete( 'o_hash', "KEYA" );
+        $root->_hash_delete( 'o_hash', "KEYB" );
+        Yote::ObjProvider::stow_all();	
     }
     $objs = Yote::ObjProvider::recycle_objects();
-    is( $objs, 2, 'hash delete  is recycled' );
+    is( $objs, 2, 'hash delete is recycled' );
 
     $root->set_o_hash( undef );
     Yote::ObjProvider::stow_all();	
     is( $root->_container_type( 'o_hash' ), '', 'container type detect no class once hash removed' );
 
     $root->add_to( { name => 'z_list', items => [ "A", "B" ] }, $root_acct );
+
     is_deeply( $root->get_z_list(), [ "A", "B" ], "add to having correct obj" );
 
     $root->insert_at( { name => 'y_list', index => 2, item => "C" }, $root_acct );
     is_deeply( $root->get_y_list(), [ "C" ], "insert at to having correct obj" );
 
     $root->add_to( { name => 'el_list', items => [ "A", "B", $o ] }, $root_acct );
+
+    my $el_list = $root->get_el_list();
     $root->insert_at( { name => 'el_list', index => 0, item => "MrZERO" }, $root_acct );
     $root->insert_at( { name => 'el_list', index => 110, item => "MrEND" }, $root_acct );
     $root->add_to( { name => 'el_list', items => [ 'EVEN FURTHER' ] }, $root_acct );
 
-    my $el_list = $root->get_el_list();
+    $el_list = $root->get_el_list();
+
     is_deeply( $el_list, [ "MrZERO", "A", "B", $o, "MrEND", "EVEN FURTHER" ], "Add to and Insert At working" );
 
     # hash insert and hash delete key
@@ -859,17 +865,17 @@ sub io_independent_tests {
     my $login_test = $root->login( { h => 'zoot', p => 'naughty' } )->{l};
     ok( $login_test, "Login Test Zoot not disabled" );
     eval {
-	$root->disable_login( $login_test, $zoot_acct ); 
+        $root->disable_login( $login_test, $zoot_acct ); 
     };
     like( $@, qr/Access Error/, "Need root to disable login" );
     $root->disable_login( $login_test, $root_acct ); 
     $login_test->set__is_disabled( 1 );
     eval {
-	$login_test = $root->login( { h => 'zoot', p => 'naughty' } );
+        $login_test = $root->login( { h => 'zoot', p => 'naughty' } );
     };
     like( $@, qr/Access Error/, "Login disabling works" );
     eval {
-	$root->enable_login( $login_test, $zoot_acct ); 
+        $root->enable_login( $login_test, $zoot_acct ); 
     };
     like( $@, qr/Access Error/, "Need root to enable login" );
     $root->enable_login( $login_test, $root_acct ); 
@@ -878,12 +884,12 @@ sub io_independent_tests {
     is( $login_test, $zoot_login, "Able to log in once reeanbled." );
 
     eval {
-	$root->disable_login( $new_master_login, $root_acct ); 
+        $root->disable_login( $new_master_login, $root_acct ); 
     };
     like( $@, qr/Cannot disable master root login/, "cannot disable master root login" );
 
     eval {
-	$root->disable_account( $master_account, $root_acct ); 
+        $root->disable_account( $master_account, $root_acct ); 
     };
     like( $@, qr/Cannot disable master root account/, "cannot disable master root account" );
 
@@ -1171,17 +1177,17 @@ sub io_independent_tests {
     $TIMEVAR = 0;
 
     my $entry = new Yote::Obj( {
- 	enabled => 1,
-	repeats => [
-	    new Yote::Obj( { repeat_infinite => 1, repeat_interval => 14 } ),
-	    new Yote::Obj( { repeat_times => 1, repeat_interval => 3 } ),
-	    ],
-	scheduled_times => [
-	    88,
-	    44,
-	    99,
-	    ],
-			       } );
+        enabled => 1,
+        repeats => [
+            new Yote::Obj( { repeat_infinite => 1, repeat_interval => 14 } ),
+            new Yote::Obj( { repeat_times => 1, repeat_interval => 3 } ),
+            ],
+            scheduled_times => [
+                88,
+                44,
+                99,
+            ],
+                               } );
     $cron->add_entry( $entry );
 
     is( $entry->get_next_time(), 3, "Cron entry 1" );
@@ -1272,19 +1278,19 @@ sub io_independent_tests {
     # one of the logins has no email : the master root
     is( $yote_root->_count( { name =>  '_emails' } ), 3, "starting emails count" );
     is( scalar keys %$root_emails, 3, "stsarting emails" );
+    if(1) {  #make this false to speed up tests
+        for( 1..1010 ) {
+            $root_handles->{ "BAD_HANDLE_$_" } = "DELME";
+            $root_emails->{ "BAD_HANDLE_$_" } = "DELME";
+        }
+        is( scalar keys %$root_handles, 1014, "Added bad handles" );
+        is( scalar keys %$root_emails, 1013, "added bad emails" );
 
-    for( 1..1010 ) {
-	$root_handles->{ "BAD_HANDLE_$_" } = "DELME";
-	$root_emails->{ "BAD_HANDLE_$_" } = "DELME";
+        Yote::ObjProvider::stow_all();
+
+        is( $yote_root->_count( { name =>  '_handles' } ), 1014, "bad handles count" );
+        is( $yote_root->_count( { name =>  '_emails' } ), 1013, "bad emails count" );
     }
-    is( scalar keys %$root_handles, 1014, "Added bad handles" );
-    is( scalar keys %$root_emails, 1013, "added bad emails" );
-
-    Yote::ObjProvider::stow_all();
-
-    is( $yote_root->_count( { name =>  '_handles' } ), 1014, "bad handles count" );
-    is( $yote_root->_count( { name =>  '_emails' } ), 1013, "bad emails count" );
-
 
     $yote_root->_purge_deleted_logins();
     is( $yote_root->_count( { name =>  '_handles' } ), 4, "back to starting handles count" );
@@ -1318,8 +1324,8 @@ sub io_independent_tests {
     is_deeply( $ro->paginate( { name => "_foo", }, $master_acct ), [], "master root can paginate root obj private container" );
     is_deeply( $ro->paginate( { name => "_foo", }, $zoot_root_acct ), [], "other root can paginate root obj private container" );
     eval { 
-	$ro->paginate( { name => "_foo", }, $toot_notroot_acct );
-	fail( "nonroot account able to paginate root obj private container" );
+        $ro->paginate( { name => "_foo", }, $toot_notroot_acct );
+        fail( "nonroot account able to paginate root obj private container" );
     };
     like( $@, qr/^Access Error/,"nonroot account unable to paginate root obj private container" );
 
@@ -1328,14 +1334,14 @@ sub io_independent_tests {
     is_deeply( $uo->paginate( { name => "_foo", }, $zoot_root_acct ), [], "other root can paginate user obj private container" );
     is_deeply( $uo->paginate( { name => "_foo", }, $toot_notroot_acct ), [], "creator can paginate user obj private container" );
     eval { 
-	$ro->paginate( { name => "_foo", }, $cute_notroot_acct );
-	fail( "nonroot account able to paginate root obj private container" );
+        $ro->paginate( { name => "_foo", }, $cute_notroot_acct );
+        fail( "nonroot account able to paginate root obj private container" );
     };
     like( $@, qr/^Access Error/,"nonroot nonowner account unable to paginate user obj private container" );
     is_deeply( $uo->paginate( { name => "foo", }, $cute_notroot_acct ), [], "nonroot, noncreator can paginate user obj public container" );
     eval { 
-	$ro->hash( { name => "foo", value => 'bar' }, $cute_notroot_acct );
-	fail( "nonroot, nocreator account able to insert into into user obj private container" );
+        $ro->hash( { name => "foo", value => 'bar' }, $cute_notroot_acct );
+        fail( "nonroot, nocreator account able to insert into into user obj private container" );
     };
     like( $@, qr/^Access Error/,"nonroot nonowner account unable to insert data into  user obj public container" );
 } #io_independent_tests
