@@ -11,6 +11,7 @@ use Yote::Hash;
 use Yote::Obj;
 use Yote::ObjManager;
 use Yote::Root;
+use Yote::IO::YoteDB;
 
 use Crypt::Passwd::XS;
 use WeakRef;
@@ -39,15 +40,7 @@ sub new {
 
 sub init {
     my $args = shift;
-    my $datapkg = 'Yote::IO::SQLite';
-    if( $args->{engine} eq 'mongo' ) {
-        $datapkg = 'Yote::IO::Mongo';
-    }
-    elsif( $args->{engine} eq 'mysql' ) {
-        $datapkg = 'Yote::IO::Mysql';
-    }
-    eval( "require $datapkg" );
-    $DATASTORE = $datapkg->new( $args );
+    $DATASTORE = new Yote::IO::YoteDB( $args );
     $DATASTORE->ensure_datastore();
 } #init
 
@@ -55,10 +48,6 @@ sub init {
 #      * PUBLIC CLASS METHODS *
 # ------------------------------------------------------------------------------------------
 
-sub commit_transaction {
-    return $DATASTORE->commit_transaction();
-}
-
 sub container_type {
     my( $host_id, $container_name ) = @_;
     return '' unless $host_id;
@@ -81,11 +70,6 @@ sub dirty {
     $Yote::ObjProvider::DIRTY->{$id} = $obj;
 } #dirty
 
-
-sub disconnect {
-    return $DATASTORE->disconnect();
-}
-
 sub fetch {
     my( $id ) = @_;
     return undef unless $id;
@@ -94,7 +78,7 @@ sub fetch {
     #
     my $ref = $Yote::ObjProvider::DIRTY->{$id} || $Yote::ObjProvider::WEAK_REFS->{$id};
 
-    if( $ref ) {
+    if( defined $ref ) {
         return $ref;
     }
     my $obj_arry = $DATASTORE->fetch( $id );
@@ -118,7 +102,6 @@ sub fetch {
         }
         else {
             eval("require $class");
-            print STDERR Data::Dumper->Dump([$class,$!,$@,$obj_arry]) if $@;
             return undef if $@;
 
             my $obj = $class->new( $id );
@@ -183,7 +166,6 @@ sub get_id {
     }
     elsif( $class eq 'HASH' ) {
         my $tied = tied %$ref;
-
         if( $tied ) {
             $tied->[0] ||= $DATASTORE->get_id( "HASH" );
             __store_weak( $tied->[0], $ref );
@@ -277,11 +259,6 @@ sub paginate {
     return [ map { xform_out( $_ ) } @{ $DATASTORE->paginate( $obj_id, $args ) } ];
 } #paginate
 
-
-#
-# Finds objects not connected to the root and recycles them.
-# This interface would be broken with the MongDB implementation.
-#
 sub recycle_objects {
     return $DATASTORE->recycle_objects( @_ );
 } #recycle_objects
@@ -291,10 +268,6 @@ sub remove_from {
     return $DATASTORE->list_delete( $list_id, xform_in( $item ) );
 } #remove_from
 
-sub start_transaction {
-    return $DATASTORE->start_transaction();
-}
-
 sub stow {
     my( $obj ) = @_;
 
@@ -438,9 +411,8 @@ sub __raw_data {
 
 sub __store_weak {
     my( $id, $ref ) = @_;
-    my $weak = $ref;
-    weaken( $weak );
-    $Yote::ObjProvider::WEAK_REFS->{$id} = $weak;
+    $Yote::ObjProvider::WEAK_REFS->{$id} = $ref;
+    weaken( $Yote::ObjProvider::WEAK_REFS->{$id} );
 } #__store_weak
 
 
@@ -472,13 +444,11 @@ It is the only module to directly interact with the datastore layer.
 
 =over 4
 
-=item commit_transaction( )
-
-Requests the data store used commit the transaction.
-
 =item container_type( host_id, container_name )
 
-returns the class name of the given container from a host class.
+Returns the class name of the given container from a host class.
+For example, if Yote::Obj $o has an array attached to its myarray field,
+The syntax is Yote::ObjProvider::container_type( $o, 'myarray' ) <--- returns 'ARRAY';
 
 =item count( container_id, args )
 
@@ -588,10 +558,6 @@ Recycles all objects in the range given if they cannot trace back a path to root
 
 Removes the items ( by value ) from the list with the given id.
 
-=item start_transaction( )
-
-Requests that the underlying data store start a transaction.
-
 =item stow( obj )
 
 This saves the hash ref, array ref or yote object argument in the data store.
